#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from dlgBase import DlgBase

import gtk
import msgBox
import taskSet
import priority

# ---======---
# DlgEditTask : allow the user to create/edit a task
# ---======---
class DlgEditTask (DlgBase) :

    #  === Constructor ===
    def __init__(self, parent) :
        DlgBase.__init__(self, parent, 'dlg-edittask', ['txtName', 'txtMessage', 'cbbPriority'])

        # Fill the combo box (priority)
        self.storage = gtk.ListStore(str)
        for p in priority.list :
            self.storage.append([p])
        self.cbbPriority.set_model(self.storage)
        cell = gtk.CellRendererText()
        self.cbbPriority.pack_start(cell, True)
        self.cbbPriority.add_attribute(cell, 'text', 0)

    # === Return the 3-tuple (name, priority, message) contained in the fields ===
    def getFields(self) :
        name    = self.txtName.get_text()
        prio    = priority.Priority(self.cbbPriority.get_active())
        message = self.getTextViewContent(self.txtMessage)

        return (name, prio, message)

    # === Manage responses sent by the dialog ===
    def onResponse(self, dialog, response, *args) :
        if response == gtk.RESPONSE_OK and self.txtName.get_text() == '' :
            msgBox.error(self.dialog, 'You must give a name to this task!')
            self.dialog.stop_emission('response')
        else :
            DlgBase.onResponse(self, dialog, response, args)

    # === Edit the given task, None for a new one ===
    def show(self, taskId) :
        # Creation mode
        if taskId == None :
            self.dialog.set_title('Create a task')
            self.txtName.set_text('')
            self.txtMessage.get_buffer().set_text('')
            self.cbbPriority.set_active(priority.default)
        # Edition mode
        else :
            task = taskSet.getInstance().get(taskId)
            self.dialog.set_title('Edit a task')
            self.txtName.set_text(task.name)
            self.txtMessage.get_buffer().set_text(task.message)
            self.cbbPriority.set_active(task.priority.level)

        return DlgBase.show(self)

# === This object is a singleton
dialog = None
def getInstance(parent) :
    global dialog
    if dialog == None :
        dialog = DlgEditTask(parent)
    return dialog
