#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from sys import exit

import gtk
import pygtk
import gtk.gdk
import gtk.glade
import taskListView
import task
import dlgEditTask
import dlgAbout
import taskSet
import msgBox
import consts

# ---======---
# Main class : create a window to interact with the user
# ---======---
class Main :

    # === Constructor ===
    def __init__(self) :
        # Create the window, retrieve widgets
        self.wTree    = gtk.glade.XML(consts.getInstance().resDir + 'win-main.glade')
        self.window   = self.wTree.get_widget('win-main')
        self.listview = taskListView.TaskListView(self.window, self.wTree.get_widget('lst-tasks'))
        self.mnuAdd   = self.wTree.get_widget('mnu-add')
        self.mnuEdit  = self.wTree.get_widget('mnu-edit')

        # Connect events
        dic_events = {
            'onWinDestroy' : self.onQuit,
            'onMenuQuit'   : self.onQuit,
            'onMenuAdd'    : self.onMenuAdd,
            'onMenuEdit'   : self.onMenuEdit,
            'onMenuAbout'  : self.onMenuAbout,
            'onMenuDelete' : self.onMenuDelete,
            'onLstClick'   : self.onLstClick,
            'onLstKey'     : self.onLstKey,
        }
        self.wTree.signal_autoconnect(dic_events)

        # Load the tasks
        taskSet.getInstance().load()
        self.listview.updateAll()

        # Main GTK loop
        gtk.main()

    # === Quit the program ===
    def onQuit(self, widget) :
        gtk.main_quit()

    # === Show the about dialog box ===
    def onMenuAbout(self, widget) :
        dlgAbout.getInstance(self.window).show()

    # === Add a new task ===
    def onMenuAdd(self, widget) :
        if dlgEditTask.getInstance(self.window).show(None) == gtk.RESPONSE_OK :
            name, priority, message = dlgEditTask.getInstance(self.window).getFields()
            taskSet.getInstance().add(name, priority, message)
            self.listview.updateAll()

    # === Edit the selected task ===
    def onMenuEdit(self, widget) :
        # Is something selected ?
        selectedId = self.listview.getSelection()
        if selectedId != -1 :
            if dlgEditTask.getInstance(self.window).show(selectedId) == gtk.RESPONSE_OK :
                name, priority, message = dlgEditTask.getInstance(self.window).getFields()
                taskSet.getInstance().update(selectedId, name, priority, message)
                self.listview.updateAll()

    # === Delete the selected task ===
    def onMenuDelete(self, widget) :
        self.listview.deleteSelection()

    # === A key was pressed in the list ===
    def onLstKey(self, list, event) :
        if gtk.gdk.keyval_name(event.keyval) == 'Delete' :
            self.listview.deleteSelection()

    # === Mouse click occurred on the list ===
    def onLstClick(self, list, event) :
        # Single right click ?
        if event.button == 3 and event.type == gtk.gdk.BUTTON_PRESS :
            list = self.wTree.get_widget('lst-tasks')
            x = int(event.x)
            y = int(event.y)
            time = event.time
            pthinfo = list.get_path_at_pos(x, y)
            if pthinfo is not None :
                path, col, cellx, celly = pthinfo
                list.grab_focus()
                list.set_cursor(path, col, 0)
                self.mnuEdit.popup( None, None, None, event.button, time)
            else :
                self.mnuAdd.popup( None, None, None, event.button, time)
        # Double left click ?
        elif event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS :
            selection = self.listview.getSelection()
            if selection != -1 :
                task = taskSet.getInstance().get(selection)
                msg  = '<b>' + task.name + '</b>\n[<i>' + str(task.priority) + '</i>]'
                if task.hasMessage() :
                    msg += '\n\n' + task.message
                msgBox.information(self.window, msg)


# ---======---
# Entry point
# ---======---
if __name__ != '__main__' :
    print 'Error : Not a module'
    exit()

# Create the main window
Main()
