#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import gtk
import msgBox
import taskSet

# ---======---
# TaskListView : manage the main ListView which displays the tasks
# ---======---
class TaskListView :

    #  === Constructor ===
    def __init__(self, parentWindow, listview) :
        self.listview     = listview
        self.parentWindow = parentWindow

        # Create a storage object
        self.storage = gtk.ListStore(int, str, str, str)
        self.listview.set_model(self.storage)

        # We use two different renderers in this ListView
        self.txtRenderer = gtk.CellRendererText()
        self.pixRenderer = gtk.CellRendererPixbuf()

        # Insert columns
        self.listview.insert_column_with_attributes(-1, '', self.pixRenderer, stock_id=1)
        self.listview.insert_column_with_attributes(-1, 'Priority', self.txtRenderer, text=2)
        self.listview.insert_column_with_attributes(-1, 'Name', self.txtRenderer, text=3)

    # === Add a task to the ListView ===
    def addTask(self, task) :
        if task.hasMessage() :
            self.storage.append([task.id, gtk.STOCK_INFO, task.priority, task.name])
        else :
            self.storage.append([task.id, None, task.priority, task.name])

    # === Return the id of the selected task, or -1 ===
    def getSelection(self) :
        model, iter = self.listview.get_selection().get_selected()
        if iter == None :
            return -1
        return model.get_value(iter, 0)

    # === If a task is selected, delete it ===
    def deleteSelection(self) :
        selection = self.getSelection()
        if selection != -1 and msgBox.question(self.parentWindow, 'Do you really want to delete this task?') == gtk.RESPONSE_YES :
            taskSet.getInstance().delete(selection)
            self.updateAll()

    # === Update the whole list ===
    def updateAll(self) :
        self.storage.clear()
        for t in taskSet.getInstance().getAll() :
            self.addTask(t)
