#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from task import Task

import xml.dom.minidom
import xml.dom.ext
import priority
import consts
import os
import task

# ---======---
# TaskSet : store the complete set of known tasks
# ---======---
class TaskSet :

    # === Constructor ===
    def __init__(self) :
        self.tasks  = {}
        self.nextId = 1

    # === Retrieve the given task ===
    def get(self, id) :
        if not self.tasks.has_key(id) :
            raise LookupError, 'No such task (id=' + str(id) + ')'
        return self.tasks[id]

    # === Add a new task to the list ===
    def add(self, name, priority, message) :
        self.tasks[self.nextId] = Task(self.nextId, name, priority, message)
        self.nextId += 1
        self.save()

    # === Update the given task ===
    def update(self, id, name, priority, message) :
        self.get(id).setProperties(name, priority, message)
        self.save()

    # === Delete the given task ===
    def delete(self, id) :
        if not self.tasks.has_key(id) :
            raise LookupError, 'No such task (id=' + str(id) + ')'
        del self.tasks[id]
        self.save()

    # === ===
    def getAll(self) :
        tasks = self.tasks.values()
        tasks.sort(task.compare)
        return tasks

    # === Save the set of tasks, if needed ===
    def save(self) :
        # Save the set to a XML document
        doc  = xml.dom.minidom.Document()
        root = doc.createElement('tasks')
        doc.appendChild(root)
        # Append each task to the root
        for task in self.tasks.values() :
            node = doc.createElement('task')
            node.setAttribute('name', task.name)
            node.setAttribute('priority', str(task.priority.level))
            node.setAttribute('message', task.message)
            root.appendChild(node)
        # Create the file
        file_object = open(consts.getInstance().tasksFile, "w")
        xml.dom.ext.PrettyPrint(doc, file_object)
        file_object.close()

    # === Load the set of tasks from the given file ===
    def load(self) :
        # Do nothing if the file does not exist
        if not os.access(consts.getInstance().tasksFile, os.F_OK) :
            return
        # It is there, so load it
        root = xml.dom.minidom.parse(consts.getInstance().tasksFile).documentElement
        for element in root.getElementsByTagName('task') :
            name     = element.getAttribute('name')
            prio     = priority.Priority(int(element.getAttribute('priority')))
            message  = element.getAttribute('message')
            self.add(name, prio, message)

# === This object is a singleton
taskSet = None
def getInstance() :
    global taskSet
    if taskSet == None :
        taskSet = TaskSet()
    return taskSet
